/**
 * @fileOverview  View methods for the use case "create book"
 * @author Gerd Wagner
 * @author Juan-Francisco Reyes
 */
/***************************************************************
 Import classes, data types and utility procedures
 ***************************************************************/
import { handleAuthentication } from "./accessControl.mjs";
import Book from "../m/Book.mjs";
import { showProgressBar, hideProgressBar } from "../../lib/util.mjs";

/***************************************************************
 Setup and handle UI Authentication
 ***************************************************************/
handleAuthentication();

/***************************************************************
 Declare variables for accessing UI elements
 ***************************************************************/
const formEl = document.forms["Book"],
  createButton = formEl["commit"],
  progressEl = document.querySelector("progress");

/***************************************************************
 Add event listeners for responsive validation
 ***************************************************************/
// add event listeners for responsive validation
formEl["isbn"].addEventListener("input", function () {
  // do not yet check the ID constraint, only before commit
  formEl["isbn"].setCustomValidity( Book.checkIsbn( formEl["isbn"].value).message);
});
formEl["title"].addEventListener("input", function () {
  formEl["title"].setCustomValidity( Book.checkTitle( formEl["title"].value).message);
});
formEl["year"].addEventListener("input", function () {
  formEl["year"].setCustomValidity( Book.checkYear( formEl["year"].value).message);
});
formEl["edition"].addEventListener("input", function () {
  formEl["edition"].setCustomValidity( Book.checkEdition( formEl["edition"].value).message);
});

/********************************************************************
 Add further event listeners, especially for the create/submit button
 ********************************************************************/
createButton.addEventListener("click", async function () {
  const formEl = document.forms["Book"],
    slots = {
    isbn: formEl["isbn"].value,
    title: formEl["title"].value,
    year: formEl["year"].value
  };
  // check constraints and set error messages
  showProgressBar( progressEl);
  formEl["isbn"].setCustomValidity(( await Book.checkIsbnAsId( slots.isbn)).message);
  formEl["title"].setCustomValidity( Book.checkTitle( slots.title).message);
  formEl["year"].setCustomValidity( Book.checkYear( slots.year).message);
  if (formEl["edition"].value) {
    slots.edition = formEl["edition"].value;
    formEl["edition"].setCustomValidity( Book.checkEdition( slots.edition).message);
  }
  if (formEl.checkValidity()) {
    await Book.add( slots);
    formEl.reset();
  }
  hideProgressBar( progressEl);
});
// neutralize the submit event
formEl.addEventListener("submit", function (e) {
  e.preventDefault();
});
