/**
 * @fileOverview  View methods for the use case "delete book"
 * @author Gerd Wagner
 * @author Juan-Francisco Reyes
 */
/***************************************************************
 Import classes, data types and utility procedures
 ***************************************************************/
import { handleAuthentication } from "./accessControl.mjs";
import Book from "../m/Book.mjs";
import { fillSelectWithOptions } from "../../lib/util.mjs";

/***************************************************************
 Setup and handle UI Authentication
 ***************************************************************/
handleAuthentication();

/***************************************************************
 Load data
 ***************************************************************/
const bookRecords = await Book.retrieveAll();

/***************************************************************
 Declare variables for accessing UI elements
 ***************************************************************/
const formEl = document.forms["Book"],
  deleteButton = formEl["commit"],
  selectBookEl = formEl["selectBook"];

/***************************************************************
 Set up (choice) widgets
 ***************************************************************/
// set up the book selection list
fillSelectWithOptions( bookRecords, selectBookEl, "isbn", "title");

/********************************************************************
 Add further event listeners, especially for the delete/submit button
 ********************************************************************/
deleteButton.addEventListener("click", function () {
  const bookIdRef = selectBookEl.value;
  if (!bookIdRef) return;
  if (confirm("Do you really want to delete this book record?")) {
    Book.destroy( bookIdRef);
    // remove deleted book from select options
    selectBookEl.remove(selectBookEl.selectedIndex);
  }
});
