/**
 * @fileOverview  View methods for the use case "retrieve and list books"
 * @author Gerd Wagner
 * @author Juan-Francisco Reyes
 */
/***************************************************************
 Import classes, data types and utility procedures
 ***************************************************************/
import { handleAuthentication } from "./accessControl.mjs";
import Book from "../m/Book.mjs";
import { showProgressBar, hideProgressBar } from "../../lib/util.mjs";

/***************************************************************
 Setup and handle UI Authentication
 ***************************************************************/
handleAuthentication();

/**********************************************************************
 Declare variables for accessing UI elements
 **********************************************************************/
const selectOrderEl = document.querySelector("main>div>div>label>select");
const tableBodyEl = document.querySelector("table#books>tbody"),
  progressEl = document.querySelector("progress");

/***************************************************************
 Create table view
 ***************************************************************/
await retrieveAndListAllBooks();

/***************************************************************
 Handle order selector
 ***************************************************************/
selectOrderEl.addEventListener("change", async function (e) {
  // invoke list with order parameter selected
  await retrieveAndListAllBooks( e.target.value);
});

/***************************************************************
 Render list of all book records
 ***************************************************************/
async function retrieveAndListAllBooks( order) {
  tableBodyEl.innerHTML = "";
  showProgressBar( progressEl);
  // load all book records using order param
  const bookRecords = await Book.retrieveAll( order);
  // for each book, create a table row with a cell for each attribute
  for (const b of bookRecords) {
    let row = tableBodyEl.insertRow();
    row.insertCell(-1).textContent = b.isbn;
    row.insertCell(-1).textContent = b.title;
    row.insertCell(-1).textContent = b.year;
    row.insertCell(-1).textContent = b.edition || "";
  }
  hideProgressBar( progressEl);
}
